@@ -119,16 +119,14 @@ BEZI = function (mu.link = "logit", sigma.link = "log", nu.link = "logit")
 ########## Density  function of Zero Inflated Beta ##########
 dBEZI = function (x, mu = 0.5, sigma = 1, nu = 0.1, log = FALSE) 
 {
-
     if (any(mu <= 0)|any(mu >= 1)) 
         stop(paste("mu must be beetwen 0 and 1 ", "\n", ""))
     if (any(sigma < 0))  #In this parametrization  sigma = phi
         stop(paste("sigma must be positive", "\n", ""))
     if (any(nu <= 0)|any(nu >= 1))  #In this parametrization  nu = alpha
         stop(paste("nu must be beetwen 0 and 1 ", "\n", ""))
-    if (any(x < 0)|any(x >= 1) ) 
-        stop(paste("x must be beetwen [0, 1)", "\n", ""))
-
+    # if (any(x < 0)|any(x >= 1) ) 
+    #     stop(paste("x must be beetwen [0, 1)", "\n", ""))
     a = mu * sigma
     b = (1 - mu) * sigma
 
@@ -138,12 +136,11 @@ dBEZI = function (x, mu = 0.5, sigma = 1, nu = 0.1, log = FALSE)
     if (log == FALSE) 
         fy <- exp(log.lik)
     else fy <- log.lik
+    fy <- ifelse( x < 0 | x >= 1, 0, fy)
     fy
 }
-
 #----------------------------------------------------------------------------------------
-########## Acumulate  function distribution of Zero Inflated Beta ##########
-
+########## Accumulate  function distribution of Zero Inflated Beta ##########
 pBEZI = function (q, mu = 0.5, sigma = 1, nu = 0.1, lower.tail = TRUE, log.p = FALSE) 
 {
 
@@ -168,6 +165,8 @@ pBEZI = function (q, mu = 0.5, sigma = 1, nu = 0.1, lower.tail = TRUE, log.p = F
     if (log.p == FALSE) 
         cdf <- cdf
     else cdf <- log(cdf)
+    cdf <- ifelse( q< 0, 0, cdf)
+    cdf <- ifelse( q >= 01, 01, cdf)
     cdf
 }
 
