@@ -147,14 +147,15 @@ dDEL<-function(x, mu=1, sigma=1, nu=.5, log=FALSE)
    if (any(mu <= 0) )  stop(paste("mu must be greater than 0 ", "\n", "")) 
    if (any(sigma <= 0) )  stop(paste("sigma must be greater than 0 ", "\n", "")) 
    if (any(nu <= 0) | any(nu >= 1))  stop(paste("nu must be between 0 and 1", "\n", "")) 
-   if (any(x < 0) )  stop(paste("x must be >=0", "\n", ""))  
+  # if (any(x < 0) )  stop(paste("x must be >=0", "\n", ""))  
     ly <- max(length(x),length(mu),length(sigma),length(nu)) 
-     x <- rep(x, length = ly)      
+     x <- rep(x, length = ly) 
+    xx <- ifelse(x < 0, 0, x)
  sigma <- rep(sigma, length = ly)
     mu <- rep(mu, length = ly)   
     nu <- rep(nu, length = ly) 
 logpy0 <- -mu*nu-(1/sigma)*(log(1+mu*sigma*(1-nu)))
-     S <- tofyDEL2(x, mu, sigma, nu)
+     S <- tofyDEL2(xx, mu, sigma, nu)
    # S <- tofyDELPORT(x, mu, sigma, nu)[,2]
  logfy <-  logpy0-lgamma(x+1)+S
  if(log==FALSE) fy <- exp(logfy) else fy <- logfy
@@ -163,6 +164,7 @@ logpy0 <- -mu*nu-(1/sigma)*(log(1+mu*sigma*(1-nu)))
                                           dPO(x, mu = mu, log = log) )
         else fy <- if (sigma<0.0001) dPO(x, mu = mu, log = log) 
                    else fy 
+  fy <- ifelse(x < 0, 0, fy)  
   fy
   }
 #----------------------------------------------------------------------------------------
@@ -254,9 +256,10 @@ pDEL <- function(q, mu = 1, sigma = 1, nu = .5, lower.tail = TRUE, log.p = FALSE
    if (any(mu <= 0) )  stop(paste("mu must be greater than 0 ", "\n", "")) 
    if (any(sigma <= 0) )  stop(paste("sigma must be greater than 0 ", "\n", "")) 
    if (any(nu <= 0) | any(nu >= 1))  stop(paste("nu must be between 0 and 1", "\n", "")) 
-   if (any(q < 0) )  stop(paste("q must be >=0", "\n", ""))    
+#   if (any(q < 0) )  stop(paste("q must be >=0", "\n", ""))    
        ly <- max(length(q),length(mu),length(sigma),length(nu)) 
-        q <- rep(q, length = ly)      
+        q <- rep(q, length = ly)   
+     #  qq <- ifelse(q < 0, 0, q)
     sigma <- rep(sigma, length = ly)
        mu <- rep(mu, length = ly)   
        nu <- rep(nu, length = ly) 
@@ -264,7 +267,8 @@ pDEL <- function(q, mu = 1, sigma = 1, nu = .5, lower.tail = TRUE, log.p = FALSE
      Vcdf <- Vectorize(fn)
       cdf <- Vcdf(q=q, mu=mu, sigma=sigma, nu=nu) 
       cdf <- if(lower.tail==TRUE) cdf else 1-cdf
-      cdf <- if(log.p==FALSE) cdf else log(cdf)                                                                    
+      cdf <- if(log.p==FALSE) cdf else log(cdf) 
+      cdf <- ifelse(q < 0, 0, cdf)
       cdf
   }
 #----------------------------------------------------------------------------------------
