@@ -27,16 +27,16 @@ EXP <- function (mu.link ="log")
 dEXP<-function(x, mu = 1, log = FALSE)
  { 
           if (any(mu <= 0) )  stop(paste("mu must be greater than 0 ", "\n", "")) 
-          if (any(x < 0) )  stop(paste("x must be >0", "\n", ""))  
+        #  if (any(x < 0) )  stop(paste("x must be >0", "\n", ""))  
           fy <- dexp(x = x, rate =1/mu, log = log)
+          fy <-ifelse(x <= 0, 0, fy)
           fy
   }
-  
 #----------------------------------------------------------------------------------------
 pEXP <- function(q, mu = 1, lower.tail = TRUE, log.p = FALSE)
   {     
           if (any(mu <= 0) )  stop(paste("mu must be greater than 0 ", "\n", "")) 
-          if (any(q < 0) )  stop(paste("y must be > 0", "\n", ""))  
+       #   if (any(q < 0) )  stop(paste("y must be > 0", "\n", ""))  
           cdf <- pexp(q, rate =1/mu, lower.tail = lower.tail, log.p = log.p)
           cdf
    }
