@@ -104,7 +104,7 @@ dNBF<-function(x, mu=1, sigma=1, nu=2, log=FALSE)
 {  
   if (any(mu <= 0) )  stop(paste("mu must be greater than 0 ", "\n", "")) 
   if (any(sigma <= 0) )  stop(paste("sigma must be greater than 0 ", "\n", "")) 
-  if (any(x < 0) )  stop(paste("x must be >=0", "\n", ""))  
+ # if (any(x < 0) )  stop(paste("x must be >=0", "\n", ""))  
     ly <- max(length(x),length(mu), length(sigma)) 
        x <- rep(x, length = ly)      
       mu <- rep(mu, length = ly) 
@@ -116,6 +116,7 @@ dNBF<-function(x, mu=1, sigma=1, nu=2, log=FALSE)
   else 
       fy <- if (sigma1<0.0001) dPO(x, mu = mu1, log = log) 
             else dnbinom(x, size=1/sigma1, mu = mu1, log = log)
+  fy <- ifelse(x < 0, 0, fy) 
   fy
 }
 #---------------------------------------------------------------------------------------- 
@@ -123,7 +124,7 @@ pNBF <- function(q, mu=1, sigma=1, nu=2, lower.tail = TRUE, log.p = FALSE)
 { 
   if (any(mu <= 0) )  stop(paste("mu must be greater than 0 ", "\n", "")) 
   if (any(sigma <= 0) )  stop(paste("sigma must be greater than 0 ", "\n", "")) 
-  if (any(q < 0) )  stop(paste("q must be >=0", "\n", ""))
+ # if (any(q < 0) )  stop(paste("q must be >=0", "\n", ""))
       ly <- max(length(q),length(mu), length(sigma)) 
        q <- rep(q, length = ly)      
       mu <- rep(mu, length = ly) 
@@ -134,6 +135,7 @@ pNBF <- function(q, mu=1, sigma=1, nu=2, lower.tail = TRUE, log.p = FALSE)
                                       ppois(q, lambda = mu1, lower.tail = lower.tail, log.p = log.p) )
   else cdf <- if (sigma1<0.0001) ppois(q, lambda = mu1, lower.tail = lower.tail, log.p = log.p)
               else pnbinom(q, size=1/sigma1, mu=mu1, lower.tail=lower.tail,log.p=log.p)
+  cdf <-ifelse(q < 0, 0, cdf) 
   cdf
 }
 #----------------------------------------------------------------------------------------
