@@ -39,24 +39,26 @@ PARETO1 <- function (mu.link = "log")
 dPARETO1<- function(x, mu = 1, log = FALSE)
 {
   if (any(mu <= 0 ) )  stop(paste("mu must be greater than 0 ", "\n", "")) 
-  if (any(x <= 0) )  stop(paste("x must be >0", "\n", ""))
+#  if (any(x <= 0) )  stop(paste("x must be >0", "\n", ""))
   ly <- max(length(x),length(mu)) 
       x <- rep(x, length = ly)      
      mu <- rep(mu, length = ly)   
    logL <- log(mu) -(mu+1) * log(1+x) #
     lik <- if (log) logL else exp(logL)
+    lik <- ifelse(x <= 0, 0, lik)
   as.numeric(lik)
 }
 #----------------------------------------------------------------------------------------
 pPARETO1 <- function(q, mu = 1, lower.tail = TRUE, log.p = FALSE)
 {
   if (any(mu <= 0) )  stop(paste("mu must be greater than 0 ", "\n", "")) 
-  if (any(q <= 0) )  stop(paste("q must be >0", "\n", ""))
+ # if (any(q <= 0) )  stop(paste("q must be >0", "\n", ""))
       cdf <- 1-(1+q)^(-mu)
   if (lower.tail == TRUE) cdf <- cdf  
   else cdf <- 1 - cdf
   if (log.p == FALSE) cdf <- cdf
    else cdf < - log(cdf)
+  cdf <-  ifelse(q <= 0, 0, cdf)   
   cdf
 }
 #----------------------------------------------------------------------------------------
