@@ -48,7 +48,7 @@ dZABI<-function(x, bd = 1, mu = 0.5, sigma = 0.1, log = FALSE)
  #browser()
           if (any(mu <= 0) |  any(mu >= 1) )  stop(paste("mu must be between 0 and 1", "\n", "")) 
           if (any(sigma <= 0) | any(sigma >= 1) )  stop(paste("sigma must be between 0 and 1", "\n", "")) 
-          if (any(x < 0) )  stop(paste("x must be 0 or greater than 0", "\n", ""))   
+  #        if (any(x < 0) )  stop(paste("x must be 0 or greater than 0", "\n", ""))   
           ly <- max(length(x),length(mu),length(sigma),length(bd)) 
               x <- rep(x, length = ly)      
           sigma <- rep(sigma, length = ly)
@@ -57,6 +57,7 @@ dZABI<-function(x, bd = 1, mu = 0.5, sigma = 0.1, log = FALSE)
           logfy <- rep(0, ly)
           logfy <- ifelse((x==0), log(sigma), log(1-sigma)+dBI(x,bd,mu,log=TRUE)-log(1-dBI(0,bd,mu)))          
           if(log == FALSE) fy <- exp(logfy) else fy <- logfy
+          fy <- ifelse(x < 0, 0, fy)
           fy
 
   }
@@ -65,14 +66,15 @@ pZABI <- function(q,bd = 1, mu = 0.5, sigma = 0.1, lower.tail = TRUE, log.p = FA
   {     
          if (any(mu <= 0) |  any(mu >= 1) )  stop(paste("mu must be between 0 and 1", "\n", ""))  
          if (any(sigma <= 0) | any(sigma >= 1) )  stop(paste("sigma must be between 0 and 1", "\n", "")) 
-         if (any(q < 0) )  stop(paste("y must be 0 or greater than 0", "\n", ""))  
+  #       if (any(q < 0) )  stop(paste("y must be 0 or greater than 0", "\n", ""))  
          cdf <- rep(0,length(q))
          cdf1 <- pbinom(q, size = bd, prob = mu, lower.tail = TRUE, log.p = FALSE)
          cdf2 <- pbinom(0, size = bd, prob = mu, lower.tail = TRUE, log.p = FALSE)
          cdf3 <- sigma+((1-sigma)*(cdf1-cdf2)/(1-cdf2))
          cdf <- ifelse((q==0),sigma,  cdf3)
          if(lower.tail == TRUE) cdf <- cdf else cdf <-1-cdf
-         if(log.p==FALSE) cdf <- cdf else cdf <- log(cdf)    
+         if(log.p==FALSE) cdf <- cdf else cdf <- log(cdf) 
+         cdf <- ifelse(q < 0, 0, cdf) 
          cdf
    }
 #-----------------------------------------------------------------------------------------
