@@ -54,9 +54,10 @@ dZAGA<-function(x, mu=1, sigma=1, nu=.1, log=FALSE)
  {        if (any(mu < 0))  stop(paste("mu must be positive", "\n", "")) 
           if (any(sigma < 0))  stop(paste("sigma must be positive", "\n", ""))
           if (any(nu < 0)|any(nu > 1))  stop(paste("nu must be between 0 and 1", "\n", ""))     
-          if (any(x < 0))  stop(paste("x must be positive", "\n", ""))  
+  #        if (any(x < 0))  stop(paste("x must be positive", "\n", ""))  
  log.lik <- ifelse(x==0, log(nu), log(1-nu)+(1/sigma^2)*log(x/(mu*sigma^2))-x/(mu*sigma^2)-log(x)-lgamma(1/sigma^2))
      if(log==FALSE) fy  <- exp(log.lik) else fy <- log.lik
+      fy <- ifelse(x < 0, 0, fy)
       fy 
   }
 #----------------------------------------------------------------------------------------
@@ -64,12 +65,13 @@ pZAGA <- function(q, mu=1, sigma=1, nu=0.1, lower.tail = TRUE, log.p = FALSE)
   {       if (any(mu < 0))  stop(paste("mu must be positive", "\n", "")) 
           if (any(sigma < 0))  stop(paste("sigma must be positive", "\n", ""))
           if (any(nu < 0)|any(nu > 1))  stop(paste("nu must be between 0 and 1", "\n", ""))     
-          if (any(q < 0))  stop(paste("y must be positive", "\n", ""))  
+    #      if (any(q < 0))  stop(paste("y must be positive", "\n", ""))  
      cdf <- pgamma(q,shape=1/sigma^2,scale=mu*sigma^2)
      cdf <- ifelse((q==0), nu, nu+(1-nu)*cdf)    
     if(lower.tail==TRUE) cdf  <- cdf else  cdf <- 1-cdf 
     if(log.p==FALSE) cdf  <- cdf else  cdf <- log(cdf) 
-    cdf
+     cdf <- ifelse(q < 0, 0, cdf) 
+     cdf
    }
 #---------------------------------------------------------------------------------------- 
 qZAGA <- function (p, mu = 1, sigma = 1, nu = 0.1, lower.tail = TRUE, 
