@@ -52,7 +52,7 @@ dZALG<-function(x, mu = 0.5, sigma = 0.1, log = FALSE)
  { 
           if (any(mu <= 0) | any(mu >= 1))  stop(paste("mu must be between 0 and 1", "\n", ""))          
           if (any(sigma <= 0) | any(sigma >= 1) )  stop(paste("sigma must be between 0 and 1", "\n", "")) 
-          if (any(x < 0) )  stop(paste("x must be 0 or greater than 0", "\n", "")) 
+     #     if (any(x < 0) )  stop(paste("x must be 0 or greater than 0", "\n", "")) 
            ly <- max(length(x),length(mu),length(sigma)) 
             x <- rep(x, length = ly)      
         sigma <- rep(sigma, length = ly)
@@ -60,6 +60,7 @@ dZALG<-function(x, mu = 0.5, sigma = 0.1, log = FALSE)
           logfy <- rep(0, ly)
           logfy <- ifelse((x==0), log(sigma), log(1-sigma)+dLG(ifelse(x==0,1,x),mu,log = TRUE))      
           if(log == FALSE) fy <- exp(logfy) else fy <- logfy
+          fy <-ifelse(x < 0, 0, fy) 
           fy
   }
 #------------------------------------------------------------------------------------------
@@ -67,7 +68,7 @@ pZALG <- function(q, mu = 0.5, sigma = 0.1, lower.tail = TRUE, log.p = FALSE)
   {     
          if (any(mu <= 0) | any(mu >= 1))  stop(paste("mu must be between 0 and 1", "\n", ""))           
          if (any(sigma <= 0) | any(sigma >= 1) )  stop(paste("sigma must be between 0 and 1", "\n", "")) 
-         if (any(q < 0) )  stop(paste("y must be 0 or greater than 0", "\n", "")) 
+     #    if (any(q < 0) )  stop(paste("y must be 0 or greater than 0", "\n", "")) 
            ly <- max(length(q),length(mu),length(sigma)) 
             q <- rep(q, length = ly)      
         sigma <- rep(sigma, length = ly)
@@ -77,7 +78,8 @@ pZALG <- function(q, mu = 0.5, sigma = 0.1, lower.tail = TRUE, log.p = FALSE)
          cdf2 <- sigma + (1-sigma)*cdf1
           cdf <- ifelse((q==0),sigma,  cdf2)
          if(lower.tail == TRUE) cdf <- cdf else cdf <-1-cdf
-         if(log.p==FALSE) cdf <- cdf else cdf <- log(cdf)    
+         if(log.p==FALSE) cdf <- cdf else cdf <- log(cdf) 
+         cdf <-ifelse(q < 0, 0, cdf) 
          cdf
    }
 #-----------------------------------------------------------------------------------------
