@@ -65,7 +65,7 @@ dZIP<-function(x, mu = 5, sigma = 0.1, log = FALSE)
  { 
           if (any(mu <= 0) )  stop(paste("mu must be greater than 0", "\n", ""))           
           if (any(sigma <= 0) | any(sigma >= 1) )  stop(paste("sigma must be between 0 and 1", "\n", "")) 
-          if (any(x < 0) )  stop(paste("x must be 0 or greater than 0", "\n", "")) 
+    #      if (any(x < 0) )  stop(paste("x must be 0 or greater than 0", "\n", "")) 
              ly <- max(length(x),length(mu),length(sigma)) 
               x <- rep(x, length = ly)      
           sigma <- rep(sigma, length = ly)
@@ -73,6 +73,7 @@ dZIP<-function(x, mu = 5, sigma = 0.1, log = FALSE)
           logfy <- rep(0, ly)
           logfy <- ifelse((x==0), log(sigma+(1-sigma)*exp(-mu)), (log(1-sigma) -mu +x*log(mu) -lgamma(x+1)))          
           if(log == FALSE) fy <- exp(logfy) else fy <- logfy
+          fy <- ifelse(x < 0, 0, fy) 
           fy
   }
 #------------------------------------------------------------------------------------------
@@ -80,7 +81,7 @@ pZIP <- function(q, mu = 5, sigma = 0.1, lower.tail = TRUE, log.p = FALSE)
   {     
          if (any(mu <= 0) )  stop(paste("mu must be greater than 0", "\n", ""))           
          if (any(sigma <= 0) | any(sigma >= 1) )  stop(paste("sigma must be between 0 and 1", "\n", "")) 
-         if (any(q < 0) )  stop(paste("y must be 0 or greater than 0", "\n", ""))
+     #    if (any(q < 0) )  stop(paste("y must be 0 or greater than 0", "\n", ""))
           ly <- max(length(q),length(mu),length(sigma)) 
            q <- rep(q, length = ly)      
        sigma <- rep(sigma, length = ly)
@@ -89,7 +90,8 @@ pZIP <- function(q, mu = 5, sigma = 0.1, lower.tail = TRUE, log.p = FALSE)
          cdf <- ppois(q, lambda = mu, lower.tail = TRUE, log.p = FALSE)
          cdf <- sigma + (1-sigma)*cdf
          if(lower.tail == TRUE) cdf <- cdf else cdf <-1-cdf
-         if(log.p==FALSE) cdf <- cdf else cdf <- log(cdf)    
+         if(log.p==FALSE) cdf <- cdf else cdf <- log(cdf)  
+         cdf <- ifelse(q < 0, 0, cdf) 
          cdf
    }
 #-----------------------------------------------------------------------------------------
