@@ -45,8 +45,9 @@ LOGNO <- function (mu.link="identity", sigma.link="log")
 dLOGNO <- function(x, mu=0, sigma=1,  log = FALSE)
  {
           if (any(sigma <= 0) )  stop(paste("sigma must be greater than 0 ", "\n", "")) 
-          if (any(x < 0) )  stop(paste("x must be >=0", "\n", ""))  
+        #  if (any(x < 0) )  stop(paste("x must be >=0", "\n", ""))  
           fy <- dlnorm(x=x, meanlog = mu, sdlog = sigma, log = log) 
+          fy <-ifelse(x <= 0, 0, fy)
           fy
   }    
 #----------------------------------------------------------------------------------------
@@ -54,7 +55,7 @@ pLOGNO <- function(q, mu=0, sigma=1,  lower.tail = TRUE, log.p = FALSE)
  {  
     #      if (any(mu <= 0) )  stop(paste("mu must be greater than 0 ", "\n", "")) 
           if (any(sigma <= 0) )  stop(paste("sigma must be greater than 0 ", "\n", "")) 
-          if (any(q < 0) )  stop(paste("y must be >=0", "\n", ""))  
+    #      if (any(q < 0) )  stop(paste("y must be >=0", "\n", ""))  
           cdf <- plnorm(q=q, meanlog = mu, sdlog = sigma, lower.tail = lower.tail, log.p = log.p)
           cdf
  }
